function [RA,ZA,fA,m] = movieRZLineal(N,b,c,H,betaR,tauf,AT)

%function [R,Z,f] = movieRZLineal(N,b,c,H,betaR,tauf,At) nos va a generar una carta de puntos (R,Z) en el instante que yo le diga
%utilizando como parametros:

%   N:         Numero de puntos a utilizar
%   betaR:      Parametro beta que modela el comportamiento gaussiano en la direccion radial que vamos a utilizar.
%   c:         Hace referencia a la altura maxima del cilindro
%   b:         Hace referencia a la distancia radial maxima del sistema que vamos a estudiar
%   tauf:      Instante hasta el que voy a generar una pelicula.
%   AT:        Saltos de tiempo que tendra mi pelicula
%   H:     Depende de las condiciones que nosotros impongamos expresa la anchura de la zona de transicion

%En este programa estamos suponieno que el perfil va a ser gaussiano en R, controlado a traves del parametro beta, y tambien gaussiano en Z,
%controlado a traves del parametro delta. Beta y delta se especificaran mas adelante, una vez estudiado el comportamiento del laser y como la
%optica podria modificar el resultado.

    [Am,betam] = coefAs(N,betaR,b);
    
%Temperaturas o niveles de temperatura que estamos buscando

    v = linspace(0,1.0,20);
    
%Vamos a tratar de generar una pelicula analizando que ocurre en diferentes instantes de tiemp

    B=0;i=1;k=1;D=0;
    Ra=-b:0.2:b;
    Za=0:0.2:c;
    
    l=1;
    
    for t=0:AT:tauf
        
        for Z=0:0.2:c
            
            for n=1:1:N
                etan = n*pi/c;
                D = D + exp(-t*etan^2)*(1-(-1)^n)*sin(etan*H)*sin(etan*Z)/(etan^2);
            end
            
            for R=-b:0.2:b
        
                for n=1:1:N
                    B = B + Am(n)*besselJ(0,betam(n)*R)*exp(-1*t*betam(n)^2);
                end
        
                f(k,i) = 2*B*D/(H*c);
                i=i+1;
                B = 0;
            end
            k = k + 1;
            i=1;
            D=0;
        end
        
        pcolor(Ra,Za,real(f))
        shading interp
        caxis([0,1]);
        title('Cilindro finito - Modelo Lineal en Z - Beta=1.5');
        B=0;i=1;k=1;
        m(l) = getframe;
        l = l + 1;
    end
    cla
    movie(m);
    movie2avi(m,'prueba_03.avi');
